# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetFlowLogServiceResult',
    'AwaitableGetFlowLogServiceResult',
    'get_flow_log_service',
    'get_flow_log_service_output',
]

@pulumi.output_type
class GetFlowLogServiceResult:
    """
    A collection of values returned by getFlowLogService.
    """
    def __init__(__self__, enable=None, id=None, status=None):
        if enable and not isinstance(enable, str):
            raise TypeError("Expected argument 'enable' to be a str")
        pulumi.set(__self__, "enable", enable)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def enable(self) -> Optional[str]:
        return pulumi.get(self, "enable")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The current service enable status.
        """
        return pulumi.get(self, "status")


class AwaitableGetFlowLogServiceResult(GetFlowLogServiceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFlowLogServiceResult(
            enable=self.enable,
            id=self.id,
            status=self.status)


def get_flow_log_service(enable: Optional[str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFlowLogServiceResult:
    """
    Using this data source can open Vpc Flow Log service automatically. If the service has been opened, it will return opened.

    For information about Vpc Flow Log and how to use it, see [What is Vpc Flow Log](https://www.alibabacloud.com/help/en/vpc/developer-reference/api-openflowlog).

    > **NOTE:** Available since v1.209.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.vpc.get_flow_log_service(enable="On")
    ```


    :param str enable: Setting the value to `On` to enable the service. If has been enabled, return the result. Default value: `Off`. Valid values: `On` and `Off`.
           
           > **NOTE:** Setting `enable = "On"` to open the Vpc Flow Log service that means you have read and agreed the [Vpc Flow Log Terms of Service](https://help.aliyun.com/zh/vpc/support/vpc-terms-of-service). The service can not closed once it is opened.
    """
    __args__ = dict()
    __args__['enable'] = enable
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:vpc/getFlowLogService:getFlowLogService', __args__, opts=opts, typ=GetFlowLogServiceResult).value

    return AwaitableGetFlowLogServiceResult(
        enable=pulumi.get(__ret__, 'enable'),
        id=pulumi.get(__ret__, 'id'),
        status=pulumi.get(__ret__, 'status'))
def get_flow_log_service_output(enable: Optional[pulumi.Input[Optional[str]]] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetFlowLogServiceResult]:
    """
    Using this data source can open Vpc Flow Log service automatically. If the service has been opened, it will return opened.

    For information about Vpc Flow Log and how to use it, see [What is Vpc Flow Log](https://www.alibabacloud.com/help/en/vpc/developer-reference/api-openflowlog).

    > **NOTE:** Available since v1.209.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.vpc.get_flow_log_service(enable="On")
    ```


    :param str enable: Setting the value to `On` to enable the service. If has been enabled, return the result. Default value: `Off`. Valid values: `On` and `Off`.
           
           > **NOTE:** Setting `enable = "On"` to open the Vpc Flow Log service that means you have read and agreed the [Vpc Flow Log Terms of Service](https://help.aliyun.com/zh/vpc/support/vpc-terms-of-service). The service can not closed once it is opened.
    """
    __args__ = dict()
    __args__['enable'] = enable
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:vpc/getFlowLogService:getFlowLogService', __args__, opts=opts, typ=GetFlowLogServiceResult)
    return __ret__.apply(lambda __response__: GetFlowLogServiceResult(
        enable=pulumi.get(__response__, 'enable'),
        id=pulumi.get(__response__, 'id'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['BandwidthPackageArgs', 'BandwidthPackage']

@pulumi.input_type
class BandwidthPackageArgs:
    def __init__(__self__, *,
                 bandwidth: pulumi.Input[int],
                 cen_bandwidth_package_name: Optional[pulumi.Input[str]] = None,
                 charge_type: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 geographic_region_a_id: Optional[pulumi.Input[str]] = None,
                 geographic_region_b_id: Optional[pulumi.Input[str]] = None,
                 geographic_region_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a BandwidthPackage resource.
        :param pulumi.Input[int] bandwidth: The bandwidth in Mbps of the bandwidth package. Cannot be less than 2Mbps.
        :param pulumi.Input[str] cen_bandwidth_package_name: The name of the bandwidth package. Defaults to null.
               
               ->**NOTE:** PrePaid mode will deduct fees from the account directly and the bandwidth package can't be deleted before expired time.
               
               ->**NOTE:** The PostPaid mode is only for test. Please open a ticket if you need.
        :param pulumi.Input[str] charge_type: Field `charge_type` has been deprecated from version 1.97.0. Use `payment_type` and instead.
        :param pulumi.Input[str] description: The description of the bandwidth package. Default to null.
        :param pulumi.Input[str] geographic_region_a_id: The area A to which the network instance belongs. Valid values: `China` | `North-America` | `Asia-Pacific` | `Europe` | `Australia`.
        :param pulumi.Input[str] geographic_region_b_id: The area B to which the network instance belongs. Valid values: `China` | `North-America` | `Asia-Pacific` | `Europe` | `Australia`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] geographic_region_ids: Field `geographic_region_ids` has been deprecated from version 1.97.0. Use `geographic_region_a_id` and `geographic_region_b_id` instead.
        :param pulumi.Input[str] name: Field `name` has been deprecated from version 1.97.0. Use `cen_bandwidth_package_name` and instead.
        :param pulumi.Input[str] payment_type: The billing method. Valid value: `PostPaid` | `PrePaid`. Default to `PrePaid`. If set to PrePaid, the bandwidth package can't be deleted before expired time.
        :param pulumi.Input[int] period: The purchase period in month. Valid value: `1`, `2`, `3`, `6`, `12`.
               > **NOTE:** The attribute `period` is only used to create Subscription instance or modify the PayAsYouGo instance to Subscription. Once effect, it will not be modified that means running `pulumi up` will not effect the resource.
        """
        pulumi.set(__self__, "bandwidth", bandwidth)
        if cen_bandwidth_package_name is not None:
            pulumi.set(__self__, "cen_bandwidth_package_name", cen_bandwidth_package_name)
        if charge_type is not None:
            warnings.warn("""Field 'charge_type' has been deprecated from version 1.98.0. Use 'payment_type' and instead.""", DeprecationWarning)
            pulumi.log.warn("""charge_type is deprecated: Field 'charge_type' has been deprecated from version 1.98.0. Use 'payment_type' and instead.""")
        if charge_type is not None:
            pulumi.set(__self__, "charge_type", charge_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if geographic_region_a_id is not None:
            pulumi.set(__self__, "geographic_region_a_id", geographic_region_a_id)
        if geographic_region_b_id is not None:
            pulumi.set(__self__, "geographic_region_b_id", geographic_region_b_id)
        if geographic_region_ids is not None:
            warnings.warn("""Field 'geographic_region_ids' has been deprecated from version 1.98.0. Use 'geographic_region_a_id' and 'geographic_region_b_id' instead.""", DeprecationWarning)
            pulumi.log.warn("""geographic_region_ids is deprecated: Field 'geographic_region_ids' has been deprecated from version 1.98.0. Use 'geographic_region_a_id' and 'geographic_region_b_id' instead.""")
        if geographic_region_ids is not None:
            pulumi.set(__self__, "geographic_region_ids", geographic_region_ids)
        if name is not None:
            warnings.warn("""Field 'name' has been deprecated from version 1.98.0. Use 'cen_bandwidth_package_name' and instead.""", DeprecationWarning)
            pulumi.log.warn("""name is deprecated: Field 'name' has been deprecated from version 1.98.0. Use 'cen_bandwidth_package_name' and instead.""")
        if name is not None:
            pulumi.set(__self__, "name", name)
        if payment_type is not None:
            pulumi.set(__self__, "payment_type", payment_type)
        if period is not None:
            pulumi.set(__self__, "period", period)

    @property
    @pulumi.getter
    def bandwidth(self) -> pulumi.Input[int]:
        """
        The bandwidth in Mbps of the bandwidth package. Cannot be less than 2Mbps.
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: pulumi.Input[int]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="cenBandwidthPackageName")
    def cen_bandwidth_package_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the bandwidth package. Defaults to null.

        ->**NOTE:** PrePaid mode will deduct fees from the account directly and the bandwidth package can't be deleted before expired time.

        ->**NOTE:** The PostPaid mode is only for test. Please open a ticket if you need.
        """
        return pulumi.get(self, "cen_bandwidth_package_name")

    @cen_bandwidth_package_name.setter
    def cen_bandwidth_package_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cen_bandwidth_package_name", value)

    @property
    @pulumi.getter(name="chargeType")
    @_utilities.deprecated("""Field 'charge_type' has been deprecated from version 1.98.0. Use 'payment_type' and instead.""")
    def charge_type(self) -> Optional[pulumi.Input[str]]:
        """
        Field `charge_type` has been deprecated from version 1.97.0. Use `payment_type` and instead.
        """
        return pulumi.get(self, "charge_type")

    @charge_type.setter
    def charge_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "charge_type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the bandwidth package. Default to null.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="geographicRegionAId")
    def geographic_region_a_id(self) -> Optional[pulumi.Input[str]]:
        """
        The area A to which the network instance belongs. Valid values: `China` | `North-America` | `Asia-Pacific` | `Europe` | `Australia`.
        """
        return pulumi.get(self, "geographic_region_a_id")

    @geographic_region_a_id.setter
    def geographic_region_a_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "geographic_region_a_id", value)

    @property
    @pulumi.getter(name="geographicRegionBId")
    def geographic_region_b_id(self) -> Optional[pulumi.Input[str]]:
        """
        The area B to which the network instance belongs. Valid values: `China` | `North-America` | `Asia-Pacific` | `Europe` | `Australia`.
        """
        return pulumi.get(self, "geographic_region_b_id")

    @geographic_region_b_id.setter
    def geographic_region_b_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "geographic_region_b_id", value)

    @property
    @pulumi.getter(name="geographicRegionIds")
    @_utilities.deprecated("""Field 'geographic_region_ids' has been deprecated from version 1.98.0. Use 'geographic_region_a_id' and 'geographic_region_b_id' instead.""")
    def geographic_region_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Field `geographic_region_ids` has been deprecated from version 1.97.0. Use `geographic_region_a_id` and `geographic_region_b_id` instead.
        """
        return pulumi.get(self, "geographic_region_ids")

    @geographic_region_ids.setter
    def geographic_region_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "geographic_region_ids", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'name' has been deprecated from version 1.98.0. Use 'cen_bandwidth_package_name' and instead.""")
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Field `name` has been deprecated from version 1.97.0. Use `cen_bandwidth_package_name` and instead.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> Optional[pulumi.Input[str]]:
        """
        The billing method. Valid value: `PostPaid` | `PrePaid`. Default to `PrePaid`. If set to PrePaid, the bandwidth package can't be deleted before expired time.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[int]]:
        """
        The purchase period in month. Valid value: `1`, `2`, `3`, `6`, `12`.
        > **NOTE:** The attribute `period` is only used to create Subscription instance or modify the PayAsYouGo instance to Subscription. Once effect, it will not be modified that means running `pulumi up` will not effect the resource.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "period", value)


@pulumi.input_type
class _BandwidthPackageState:
    def __init__(__self__, *,
                 bandwidth: Optional[pulumi.Input[int]] = None,
                 cen_bandwidth_package_name: Optional[pulumi.Input[str]] = None,
                 charge_type: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 expired_time: Optional[pulumi.Input[str]] = None,
                 geographic_region_a_id: Optional[pulumi.Input[str]] = None,
                 geographic_region_b_id: Optional[pulumi.Input[str]] = None,
                 geographic_region_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering BandwidthPackage resources.
        :param pulumi.Input[int] bandwidth: The bandwidth in Mbps of the bandwidth package. Cannot be less than 2Mbps.
        :param pulumi.Input[str] cen_bandwidth_package_name: The name of the bandwidth package. Defaults to null.
               
               ->**NOTE:** PrePaid mode will deduct fees from the account directly and the bandwidth package can't be deleted before expired time.
               
               ->**NOTE:** The PostPaid mode is only for test. Please open a ticket if you need.
        :param pulumi.Input[str] charge_type: Field `charge_type` has been deprecated from version 1.97.0. Use `payment_type` and instead.
        :param pulumi.Input[str] description: The description of the bandwidth package. Default to null.
        :param pulumi.Input[str] expired_time: The time of the bandwidth package to expire.
        :param pulumi.Input[str] geographic_region_a_id: The area A to which the network instance belongs. Valid values: `China` | `North-America` | `Asia-Pacific` | `Europe` | `Australia`.
        :param pulumi.Input[str] geographic_region_b_id: The area B to which the network instance belongs. Valid values: `China` | `North-America` | `Asia-Pacific` | `Europe` | `Australia`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] geographic_region_ids: Field `geographic_region_ids` has been deprecated from version 1.97.0. Use `geographic_region_a_id` and `geographic_region_b_id` instead.
        :param pulumi.Input[str] name: Field `name` has been deprecated from version 1.97.0. Use `cen_bandwidth_package_name` and instead.
        :param pulumi.Input[str] payment_type: The billing method. Valid value: `PostPaid` | `PrePaid`. Default to `PrePaid`. If set to PrePaid, the bandwidth package can't be deleted before expired time.
        :param pulumi.Input[int] period: The purchase period in month. Valid value: `1`, `2`, `3`, `6`, `12`.
               > **NOTE:** The attribute `period` is only used to create Subscription instance or modify the PayAsYouGo instance to Subscription. Once effect, it will not be modified that means running `pulumi up` will not effect the resource.
        :param pulumi.Input[str] status: The association status of the bandwidth package.
        """
        if bandwidth is not None:
            pulumi.set(__self__, "bandwidth", bandwidth)
        if cen_bandwidth_package_name is not None:
            pulumi.set(__self__, "cen_bandwidth_package_name", cen_bandwidth_package_name)
        if charge_type is not None:
            warnings.warn("""Field 'charge_type' has been deprecated from version 1.98.0. Use 'payment_type' and instead.""", DeprecationWarning)
            pulumi.log.warn("""charge_type is deprecated: Field 'charge_type' has been deprecated from version 1.98.0. Use 'payment_type' and instead.""")
        if charge_type is not None:
            pulumi.set(__self__, "charge_type", charge_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if expired_time is not None:
            pulumi.set(__self__, "expired_time", expired_time)
        if geographic_region_a_id is not None:
            pulumi.set(__self__, "geographic_region_a_id", geographic_region_a_id)
        if geographic_region_b_id is not None:
            pulumi.set(__self__, "geographic_region_b_id", geographic_region_b_id)
        if geographic_region_ids is not None:
            warnings.warn("""Field 'geographic_region_ids' has been deprecated from version 1.98.0. Use 'geographic_region_a_id' and 'geographic_region_b_id' instead.""", DeprecationWarning)
            pulumi.log.warn("""geographic_region_ids is deprecated: Field 'geographic_region_ids' has been deprecated from version 1.98.0. Use 'geographic_region_a_id' and 'geographic_region_b_id' instead.""")
        if geographic_region_ids is not None:
            pulumi.set(__self__, "geographic_region_ids", geographic_region_ids)
        if name is not None:
            warnings.warn("""Field 'name' has been deprecated from version 1.98.0. Use 'cen_bandwidth_package_name' and instead.""", DeprecationWarning)
            pulumi.log.warn("""name is deprecated: Field 'name' has been deprecated from version 1.98.0. Use 'cen_bandwidth_package_name' and instead.""")
        if name is not None:
            pulumi.set(__self__, "name", name)
        if payment_type is not None:
            pulumi.set(__self__, "payment_type", payment_type)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[pulumi.Input[int]]:
        """
        The bandwidth in Mbps of the bandwidth package. Cannot be less than 2Mbps.
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="cenBandwidthPackageName")
    def cen_bandwidth_package_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the bandwidth package. Defaults to null.

        ->**NOTE:** PrePaid mode will deduct fees from the account directly and the bandwidth package can't be deleted before expired time.

        ->**NOTE:** The PostPaid mode is only for test. Please open a ticket if you need.
        """
        return pulumi.get(self, "cen_bandwidth_package_name")

    @cen_bandwidth_package_name.setter
    def cen_bandwidth_package_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cen_bandwidth_package_name", value)

    @property
    @pulumi.getter(name="chargeType")
    @_utilities.deprecated("""Field 'charge_type' has been deprecated from version 1.98.0. Use 'payment_type' and instead.""")
    def charge_type(self) -> Optional[pulumi.Input[str]]:
        """
        Field `charge_type` has been deprecated from version 1.97.0. Use `payment_type` and instead.
        """
        return pulumi.get(self, "charge_type")

    @charge_type.setter
    def charge_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "charge_type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the bandwidth package. Default to null.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> Optional[pulumi.Input[str]]:
        """
        The time of the bandwidth package to expire.
        """
        return pulumi.get(self, "expired_time")

    @expired_time.setter
    def expired_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "expired_time", value)

    @property
    @pulumi.getter(name="geographicRegionAId")
    def geographic_region_a_id(self) -> Optional[pulumi.Input[str]]:
        """
        The area A to which the network instance belongs. Valid values: `China` | `North-America` | `Asia-Pacific` | `Europe` | `Australia`.
        """
        return pulumi.get(self, "geographic_region_a_id")

    @geographic_region_a_id.setter
    def geographic_region_a_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "geographic_region_a_id", value)

    @property
    @pulumi.getter(name="geographicRegionBId")
    def geographic_region_b_id(self) -> Optional[pulumi.Input[str]]:
        """
        The area B to which the network instance belongs. Valid values: `China` | `North-America` | `Asia-Pacific` | `Europe` | `Australia`.
        """
        return pulumi.get(self, "geographic_region_b_id")

    @geographic_region_b_id.setter
    def geographic_region_b_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "geographic_region_b_id", value)

    @property
    @pulumi.getter(name="geographicRegionIds")
    @_utilities.deprecated("""Field 'geographic_region_ids' has been deprecated from version 1.98.0. Use 'geographic_region_a_id' and 'geographic_region_b_id' instead.""")
    def geographic_region_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Field `geographic_region_ids` has been deprecated from version 1.97.0. Use `geographic_region_a_id` and `geographic_region_b_id` instead.
        """
        return pulumi.get(self, "geographic_region_ids")

    @geographic_region_ids.setter
    def geographic_region_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "geographic_region_ids", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'name' has been deprecated from version 1.98.0. Use 'cen_bandwidth_package_name' and instead.""")
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Field `name` has been deprecated from version 1.97.0. Use `cen_bandwidth_package_name` and instead.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> Optional[pulumi.Input[str]]:
        """
        The billing method. Valid value: `PostPaid` | `PrePaid`. Default to `PrePaid`. If set to PrePaid, the bandwidth package can't be deleted before expired time.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[int]]:
        """
        The purchase period in month. Valid value: `1`, `2`, `3`, `6`, `12`.
        > **NOTE:** The attribute `period` is only used to create Subscription instance or modify the PayAsYouGo instance to Subscription. Once effect, it will not be modified that means running `pulumi up` will not effect the resource.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The association status of the bandwidth package.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class BandwidthPackage(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bandwidth: Optional[pulumi.Input[int]] = None,
                 cen_bandwidth_package_name: Optional[pulumi.Input[str]] = None,
                 charge_type: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 geographic_region_a_id: Optional[pulumi.Input[str]] = None,
                 geographic_region_b_id: Optional[pulumi.Input[str]] = None,
                 geographic_region_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        ## Import

        CEN bandwidth package can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cen/bandwidthPackage:BandwidthPackage example cenbwp-abc123456
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] bandwidth: The bandwidth in Mbps of the bandwidth package. Cannot be less than 2Mbps.
        :param pulumi.Input[str] cen_bandwidth_package_name: The name of the bandwidth package. Defaults to null.
               
               ->**NOTE:** PrePaid mode will deduct fees from the account directly and the bandwidth package can't be deleted before expired time.
               
               ->**NOTE:** The PostPaid mode is only for test. Please open a ticket if you need.
        :param pulumi.Input[str] charge_type: Field `charge_type` has been deprecated from version 1.97.0. Use `payment_type` and instead.
        :param pulumi.Input[str] description: The description of the bandwidth package. Default to null.
        :param pulumi.Input[str] geographic_region_a_id: The area A to which the network instance belongs. Valid values: `China` | `North-America` | `Asia-Pacific` | `Europe` | `Australia`.
        :param pulumi.Input[str] geographic_region_b_id: The area B to which the network instance belongs. Valid values: `China` | `North-America` | `Asia-Pacific` | `Europe` | `Australia`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] geographic_region_ids: Field `geographic_region_ids` has been deprecated from version 1.97.0. Use `geographic_region_a_id` and `geographic_region_b_id` instead.
        :param pulumi.Input[str] name: Field `name` has been deprecated from version 1.97.0. Use `cen_bandwidth_package_name` and instead.
        :param pulumi.Input[str] payment_type: The billing method. Valid value: `PostPaid` | `PrePaid`. Default to `PrePaid`. If set to PrePaid, the bandwidth package can't be deleted before expired time.
        :param pulumi.Input[int] period: The purchase period in month. Valid value: `1`, `2`, `3`, `6`, `12`.
               > **NOTE:** The attribute `period` is only used to create Subscription instance or modify the PayAsYouGo instance to Subscription. Once effect, it will not be modified that means running `pulumi up` will not effect the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BandwidthPackageArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        CEN bandwidth package can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cen/bandwidthPackage:BandwidthPackage example cenbwp-abc123456
        ```

        :param str resource_name: The name of the resource.
        :param BandwidthPackageArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BandwidthPackageArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bandwidth: Optional[pulumi.Input[int]] = None,
                 cen_bandwidth_package_name: Optional[pulumi.Input[str]] = None,
                 charge_type: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 geographic_region_a_id: Optional[pulumi.Input[str]] = None,
                 geographic_region_b_id: Optional[pulumi.Input[str]] = None,
                 geographic_region_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BandwidthPackageArgs.__new__(BandwidthPackageArgs)

            if bandwidth is None and not opts.urn:
                raise TypeError("Missing required property 'bandwidth'")
            __props__.__dict__["bandwidth"] = bandwidth
            __props__.__dict__["cen_bandwidth_package_name"] = cen_bandwidth_package_name
            __props__.__dict__["charge_type"] = charge_type
            __props__.__dict__["description"] = description
            __props__.__dict__["geographic_region_a_id"] = geographic_region_a_id
            __props__.__dict__["geographic_region_b_id"] = geographic_region_b_id
            __props__.__dict__["geographic_region_ids"] = geographic_region_ids
            __props__.__dict__["name"] = name
            __props__.__dict__["payment_type"] = payment_type
            __props__.__dict__["period"] = period
            __props__.__dict__["expired_time"] = None
            __props__.__dict__["status"] = None
        super(BandwidthPackage, __self__).__init__(
            'alicloud:cen/bandwidthPackage:BandwidthPackage',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bandwidth: Optional[pulumi.Input[int]] = None,
            cen_bandwidth_package_name: Optional[pulumi.Input[str]] = None,
            charge_type: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            expired_time: Optional[pulumi.Input[str]] = None,
            geographic_region_a_id: Optional[pulumi.Input[str]] = None,
            geographic_region_b_id: Optional[pulumi.Input[str]] = None,
            geographic_region_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            payment_type: Optional[pulumi.Input[str]] = None,
            period: Optional[pulumi.Input[int]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'BandwidthPackage':
        """
        Get an existing BandwidthPackage resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] bandwidth: The bandwidth in Mbps of the bandwidth package. Cannot be less than 2Mbps.
        :param pulumi.Input[str] cen_bandwidth_package_name: The name of the bandwidth package. Defaults to null.
               
               ->**NOTE:** PrePaid mode will deduct fees from the account directly and the bandwidth package can't be deleted before expired time.
               
               ->**NOTE:** The PostPaid mode is only for test. Please open a ticket if you need.
        :param pulumi.Input[str] charge_type: Field `charge_type` has been deprecated from version 1.97.0. Use `payment_type` and instead.
        :param pulumi.Input[str] description: The description of the bandwidth package. Default to null.
        :param pulumi.Input[str] expired_time: The time of the bandwidth package to expire.
        :param pulumi.Input[str] geographic_region_a_id: The area A to which the network instance belongs. Valid values: `China` | `North-America` | `Asia-Pacific` | `Europe` | `Australia`.
        :param pulumi.Input[str] geographic_region_b_id: The area B to which the network instance belongs. Valid values: `China` | `North-America` | `Asia-Pacific` | `Europe` | `Australia`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] geographic_region_ids: Field `geographic_region_ids` has been deprecated from version 1.97.0. Use `geographic_region_a_id` and `geographic_region_b_id` instead.
        :param pulumi.Input[str] name: Field `name` has been deprecated from version 1.97.0. Use `cen_bandwidth_package_name` and instead.
        :param pulumi.Input[str] payment_type: The billing method. Valid value: `PostPaid` | `PrePaid`. Default to `PrePaid`. If set to PrePaid, the bandwidth package can't be deleted before expired time.
        :param pulumi.Input[int] period: The purchase period in month. Valid value: `1`, `2`, `3`, `6`, `12`.
               > **NOTE:** The attribute `period` is only used to create Subscription instance or modify the PayAsYouGo instance to Subscription. Once effect, it will not be modified that means running `pulumi up` will not effect the resource.
        :param pulumi.Input[str] status: The association status of the bandwidth package.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BandwidthPackageState.__new__(_BandwidthPackageState)

        __props__.__dict__["bandwidth"] = bandwidth
        __props__.__dict__["cen_bandwidth_package_name"] = cen_bandwidth_package_name
        __props__.__dict__["charge_type"] = charge_type
        __props__.__dict__["description"] = description
        __props__.__dict__["expired_time"] = expired_time
        __props__.__dict__["geographic_region_a_id"] = geographic_region_a_id
        __props__.__dict__["geographic_region_b_id"] = geographic_region_b_id
        __props__.__dict__["geographic_region_ids"] = geographic_region_ids
        __props__.__dict__["name"] = name
        __props__.__dict__["payment_type"] = payment_type
        __props__.__dict__["period"] = period
        __props__.__dict__["status"] = status
        return BandwidthPackage(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def bandwidth(self) -> pulumi.Output[int]:
        """
        The bandwidth in Mbps of the bandwidth package. Cannot be less than 2Mbps.
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="cenBandwidthPackageName")
    def cen_bandwidth_package_name(self) -> pulumi.Output[str]:
        """
        The name of the bandwidth package. Defaults to null.

        ->**NOTE:** PrePaid mode will deduct fees from the account directly and the bandwidth package can't be deleted before expired time.

        ->**NOTE:** The PostPaid mode is only for test. Please open a ticket if you need.
        """
        return pulumi.get(self, "cen_bandwidth_package_name")

    @property
    @pulumi.getter(name="chargeType")
    @_utilities.deprecated("""Field 'charge_type' has been deprecated from version 1.98.0. Use 'payment_type' and instead.""")
    def charge_type(self) -> pulumi.Output[str]:
        """
        Field `charge_type` has been deprecated from version 1.97.0. Use `payment_type` and instead.
        """
        return pulumi.get(self, "charge_type")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the bandwidth package. Default to null.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> pulumi.Output[str]:
        """
        The time of the bandwidth package to expire.
        """
        return pulumi.get(self, "expired_time")

    @property
    @pulumi.getter(name="geographicRegionAId")
    def geographic_region_a_id(self) -> pulumi.Output[str]:
        """
        The area A to which the network instance belongs. Valid values: `China` | `North-America` | `Asia-Pacific` | `Europe` | `Australia`.
        """
        return pulumi.get(self, "geographic_region_a_id")

    @property
    @pulumi.getter(name="geographicRegionBId")
    def geographic_region_b_id(self) -> pulumi.Output[str]:
        """
        The area B to which the network instance belongs. Valid values: `China` | `North-America` | `Asia-Pacific` | `Europe` | `Australia`.
        """
        return pulumi.get(self, "geographic_region_b_id")

    @property
    @pulumi.getter(name="geographicRegionIds")
    @_utilities.deprecated("""Field 'geographic_region_ids' has been deprecated from version 1.98.0. Use 'geographic_region_a_id' and 'geographic_region_b_id' instead.""")
    def geographic_region_ids(self) -> pulumi.Output[Sequence[str]]:
        """
        Field `geographic_region_ids` has been deprecated from version 1.97.0. Use `geographic_region_a_id` and `geographic_region_b_id` instead.
        """
        return pulumi.get(self, "geographic_region_ids")

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'name' has been deprecated from version 1.98.0. Use 'cen_bandwidth_package_name' and instead.""")
    def name(self) -> pulumi.Output[str]:
        """
        Field `name` has been deprecated from version 1.97.0. Use `cen_bandwidth_package_name` and instead.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Output[str]:
        """
        The billing method. Valid value: `PostPaid` | `PrePaid`. Default to `PrePaid`. If set to PrePaid, the bandwidth package can't be deleted before expired time.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter
    def period(self) -> pulumi.Output[Optional[int]]:
        """
        The purchase period in month. Valid value: `1`, `2`, `3`, `6`, `12`.
        > **NOTE:** The attribute `period` is only used to create Subscription instance or modify the PayAsYouGo instance to Subscription. Once effect, it will not be modified that means running `pulumi up` will not effect the resource.
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The association status of the bandwidth package.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetBaseInstancesResult',
    'AwaitableGetBaseInstancesResult',
    'get_base_instances',
    'get_base_instances_output',
]

@pulumi.output_type
class GetBaseInstancesResult:
    """
    A collection of values returned by getBaseInstances.
    """
    def __init__(__self__, enable_details=None, id=None, ids=None, instance_id=None, instance_name=None, instances=None, name_regex=None, names=None, output_file=None, page_number=None, page_size=None, resource_group_id=None, search_key=None, status=None):
        if enable_details and not isinstance(enable_details, bool):
            raise TypeError("Expected argument 'enable_details' to be a bool")
        pulumi.set(__self__, "enable_details", enable_details)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if instance_name and not isinstance(instance_name, str):
            raise TypeError("Expected argument 'instance_name' to be a str")
        pulumi.set(__self__, "instance_name", instance_name)
        if instances and not isinstance(instances, list):
            raise TypeError("Expected argument 'instances' to be a list")
        pulumi.set(__self__, "instances", instances)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if page_number and not isinstance(page_number, int):
            raise TypeError("Expected argument 'page_number' to be a int")
        pulumi.set(__self__, "page_number", page_number)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if resource_group_id and not isinstance(resource_group_id, str):
            raise TypeError("Expected argument 'resource_group_id' to be a str")
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        if search_key and not isinstance(search_key, str):
            raise TypeError("Expected argument 'search_key' to be a str")
        pulumi.set(__self__, "search_key", search_key)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="enableDetails")
    def enable_details(self) -> Optional[bool]:
        return pulumi.get(self, "enable_details")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[str]:
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> Optional[str]:
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter
    def instances(self) -> Sequence['outputs.GetBaseInstancesInstanceResult']:
        return pulumi.get(self, "instances")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="pageNumber")
    def page_number(self) -> Optional[int]:
        return pulumi.get(self, "page_number")

    @property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[int]:
        return pulumi.get(self, "page_size")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[str]:
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="searchKey")
    def search_key(self) -> Optional[str]:
        return pulumi.get(self, "search_key")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        return pulumi.get(self, "status")


class AwaitableGetBaseInstancesResult(GetBaseInstancesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBaseInstancesResult(
            enable_details=self.enable_details,
            id=self.id,
            ids=self.ids,
            instance_id=self.instance_id,
            instance_name=self.instance_name,
            instances=self.instances,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            page_number=self.page_number,
            page_size=self.page_size,
            resource_group_id=self.resource_group_id,
            search_key=self.search_key,
            status=self.status)


def get_base_instances(enable_details: Optional[bool] = None,
                       ids: Optional[Sequence[str]] = None,
                       instance_id: Optional[str] = None,
                       instance_name: Optional[str] = None,
                       name_regex: Optional[str] = None,
                       output_file: Optional[str] = None,
                       page_number: Optional[int] = None,
                       page_size: Optional[int] = None,
                       resource_group_id: Optional[str] = None,
                       search_key: Optional[str] = None,
                       status: Optional[str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBaseInstancesResult:
    """
    This data source provides the Ocean Base Instances of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.203.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.ocean.get_base_instances()
    pulumi.export("oceanBaseInstanceId1", ids.instances[0].id)
    name_regex = alicloud.ocean.get_base_instances(name_regex="^my-Instance")
    pulumi.export("oceanBaseInstanceId2", name_regex.instances[0].id)
    ```


    :param Sequence[str] ids: A list of Instance IDs.
    :param str instance_id: OceanBase cluster ID.
    :param str instance_name: OceanBase cluster name. The length is 1 to 20 English or Chinese characters. If this parameter is not specified, the default value is the InstanceId of the cluster.
    :param str name_regex: A regex string to filter results by Instance name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str resource_group_id: The ID of the enterprise resource group to which the instance resides.
    :param str search_key: The filter keyword for the query list.
    :param str status: The status of the Instance. Value range: `PENDING_CREATE`, `ONLINE`, `TENANT_CREATING`, `TENANT_SPEC_MODIFYING`, `EXPANDING`, `REDUCING`, `SPEC_UPGRADING`, `DISK_UPGRADING`, `WHITE_LIST_MODIFYING`, `PARAMETER_MODIFYING`, `SSL_MODIFYING`, `PREPAID_EXPIRE_CLOSED`, `ARREARS_CLOSED`, `PENDING_DELETE`.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['instanceId'] = instance_id
    __args__['instanceName'] = instance_name
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['resourceGroupId'] = resource_group_id
    __args__['searchKey'] = search_key
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:ocean/getBaseInstances:getBaseInstances', __args__, opts=opts, typ=GetBaseInstancesResult).value

    return AwaitableGetBaseInstancesResult(
        enable_details=pulumi.get(__ret__, 'enable_details'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        instance_name=pulumi.get(__ret__, 'instance_name'),
        instances=pulumi.get(__ret__, 'instances'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        page_number=pulumi.get(__ret__, 'page_number'),
        page_size=pulumi.get(__ret__, 'page_size'),
        resource_group_id=pulumi.get(__ret__, 'resource_group_id'),
        search_key=pulumi.get(__ret__, 'search_key'),
        status=pulumi.get(__ret__, 'status'))
def get_base_instances_output(enable_details: Optional[pulumi.Input[Optional[bool]]] = None,
                              ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                              instance_id: Optional[pulumi.Input[Optional[str]]] = None,
                              instance_name: Optional[pulumi.Input[Optional[str]]] = None,
                              name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                              output_file: Optional[pulumi.Input[Optional[str]]] = None,
                              page_number: Optional[pulumi.Input[Optional[int]]] = None,
                              page_size: Optional[pulumi.Input[Optional[int]]] = None,
                              resource_group_id: Optional[pulumi.Input[Optional[str]]] = None,
                              search_key: Optional[pulumi.Input[Optional[str]]] = None,
                              status: Optional[pulumi.Input[Optional[str]]] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetBaseInstancesResult]:
    """
    This data source provides the Ocean Base Instances of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.203.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.ocean.get_base_instances()
    pulumi.export("oceanBaseInstanceId1", ids.instances[0].id)
    name_regex = alicloud.ocean.get_base_instances(name_regex="^my-Instance")
    pulumi.export("oceanBaseInstanceId2", name_regex.instances[0].id)
    ```


    :param Sequence[str] ids: A list of Instance IDs.
    :param str instance_id: OceanBase cluster ID.
    :param str instance_name: OceanBase cluster name. The length is 1 to 20 English or Chinese characters. If this parameter is not specified, the default value is the InstanceId of the cluster.
    :param str name_regex: A regex string to filter results by Instance name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str resource_group_id: The ID of the enterprise resource group to which the instance resides.
    :param str search_key: The filter keyword for the query list.
    :param str status: The status of the Instance. Value range: `PENDING_CREATE`, `ONLINE`, `TENANT_CREATING`, `TENANT_SPEC_MODIFYING`, `EXPANDING`, `REDUCING`, `SPEC_UPGRADING`, `DISK_UPGRADING`, `WHITE_LIST_MODIFYING`, `PARAMETER_MODIFYING`, `SSL_MODIFYING`, `PREPAID_EXPIRE_CLOSED`, `ARREARS_CLOSED`, `PENDING_DELETE`.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['instanceId'] = instance_id
    __args__['instanceName'] = instance_name
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['resourceGroupId'] = resource_group_id
    __args__['searchKey'] = search_key
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:ocean/getBaseInstances:getBaseInstances', __args__, opts=opts, typ=GetBaseInstancesResult)
    return __ret__.apply(lambda __response__: GetBaseInstancesResult(
        enable_details=pulumi.get(__response__, 'enable_details'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        instance_name=pulumi.get(__response__, 'instance_name'),
        instances=pulumi.get(__response__, 'instances'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        page_number=pulumi.get(__response__, 'page_number'),
        page_size=pulumi.get(__response__, 'page_size'),
        resource_group_id=pulumi.get(__response__, 'resource_group_id'),
        search_key=pulumi.get(__response__, 'search_key'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RdsInstanceCrossBackupPolicyArgs', 'RdsInstanceCrossBackupPolicy']

@pulumi.input_type
class RdsInstanceCrossBackupPolicyArgs:
    def __init__(__self__, *,
                 cross_backup_region: pulumi.Input[str],
                 instance_id: pulumi.Input[str],
                 log_backup_enabled: Optional[pulumi.Input[str]] = None,
                 retention: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a RdsInstanceCrossBackupPolicy resource.
        :param pulumi.Input[str] cross_backup_region: The ID of the destination region where the cross-region backup files of the instance are stored.
        :param pulumi.Input[str] instance_id: The ID of the instance.
        :param pulumi.Input[str] log_backup_enabled: The status of the cross-region log backup feature on the instance. Valid values:
               - Enable: Enables the feature.
               - Disabled: Disables the feature.
        :param pulumi.Input[int] retention: The number of days for which the cross-region backup files of the instance are retained. Valid values: 7 to 1825. Default value: 7.
        """
        pulumi.set(__self__, "cross_backup_region", cross_backup_region)
        pulumi.set(__self__, "instance_id", instance_id)
        if log_backup_enabled is not None:
            pulumi.set(__self__, "log_backup_enabled", log_backup_enabled)
        if retention is not None:
            pulumi.set(__self__, "retention", retention)

    @property
    @pulumi.getter(name="crossBackupRegion")
    def cross_backup_region(self) -> pulumi.Input[str]:
        """
        The ID of the destination region where the cross-region backup files of the instance are stored.
        """
        return pulumi.get(self, "cross_backup_region")

    @cross_backup_region.setter
    def cross_backup_region(self, value: pulumi.Input[str]):
        pulumi.set(self, "cross_backup_region", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[str]:
        """
        The ID of the instance.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="logBackupEnabled")
    def log_backup_enabled(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the cross-region log backup feature on the instance. Valid values:
        - Enable: Enables the feature.
        - Disabled: Disables the feature.
        """
        return pulumi.get(self, "log_backup_enabled")

    @log_backup_enabled.setter
    def log_backup_enabled(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "log_backup_enabled", value)

    @property
    @pulumi.getter
    def retention(self) -> Optional[pulumi.Input[int]]:
        """
        The number of days for which the cross-region backup files of the instance are retained. Valid values: 7 to 1825. Default value: 7.
        """
        return pulumi.get(self, "retention")

    @retention.setter
    def retention(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "retention", value)


@pulumi.input_type
class _RdsInstanceCrossBackupPolicyState:
    def __init__(__self__, *,
                 backup_enabled: Optional[pulumi.Input[str]] = None,
                 backup_enabled_time: Optional[pulumi.Input[str]] = None,
                 cross_backup_region: Optional[pulumi.Input[str]] = None,
                 cross_backup_type: Optional[pulumi.Input[str]] = None,
                 db_instance_status: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 lock_mode: Optional[pulumi.Input[str]] = None,
                 log_backup_enabled: Optional[pulumi.Input[str]] = None,
                 log_backup_enabled_time: Optional[pulumi.Input[str]] = None,
                 retent_type: Optional[pulumi.Input[str]] = None,
                 retention: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering RdsInstanceCrossBackupPolicy resources.
        :param pulumi.Input[str] backup_enabled: The status of the overall cross-region backup switch on the instance. Valid values:
               - Disabled
               - Enable
        :param pulumi.Input[str] backup_enabled_time: The time when cross-region backup was enabled on the instance. The time follows the ISO 8601 standard in the yyyy-MM-ddTHH:mm:ssZ format. The time is displayed in UTC.
        :param pulumi.Input[str] cross_backup_region: The ID of the destination region where the cross-region backup files of the instance are stored.
        :param pulumi.Input[str] cross_backup_type: The policy that is used to save cross-region backups of the instance. Default value: 1. The default value 1 indicates that all cross-region backups are saved.
        :param pulumi.Input[str] db_instance_status: The state of the instance. For more information, see Instance status.
        :param pulumi.Input[str] instance_id: The ID of the instance.
        :param pulumi.Input[str] lock_mode: The lock status of the instance. Valid values:
               - Unlock: The instance is not locked.
               - ManualLock: The instance is manually locked.
               - LockByExpiration: The instance is locked upon expiration.
               - LockByRestoration: The instance is automatically locked before a rollback.
               - LockByDiskQuota: The instance is automatically locked because its storage space is exhausted. In this situation, the instance is inaccessible.
        :param pulumi.Input[str] log_backup_enabled: The status of the cross-region log backup feature on the instance. Valid values:
               - Enable: Enables the feature.
               - Disabled: Disables the feature.
        :param pulumi.Input[str] log_backup_enabled_time: The time when cross-region log backup was enabled on the instance. The time follows the ISO 8601 standard in the yyyy-MM-ddTHH:mm:ssZ format. The time is displayed in UTC.
        :param pulumi.Input[str] retent_type: The policy that is used to retain cross-region backups of the instance. Default value: 1. The default value 1 indicate that cross-region backups are retained based on the specified retention period.
        :param pulumi.Input[int] retention: The number of days for which the cross-region backup files of the instance are retained. Valid values: 7 to 1825. Default value: 7.
        """
        if backup_enabled is not None:
            pulumi.set(__self__, "backup_enabled", backup_enabled)
        if backup_enabled_time is not None:
            pulumi.set(__self__, "backup_enabled_time", backup_enabled_time)
        if cross_backup_region is not None:
            pulumi.set(__self__, "cross_backup_region", cross_backup_region)
        if cross_backup_type is not None:
            pulumi.set(__self__, "cross_backup_type", cross_backup_type)
        if db_instance_status is not None:
            pulumi.set(__self__, "db_instance_status", db_instance_status)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if lock_mode is not None:
            pulumi.set(__self__, "lock_mode", lock_mode)
        if log_backup_enabled is not None:
            pulumi.set(__self__, "log_backup_enabled", log_backup_enabled)
        if log_backup_enabled_time is not None:
            pulumi.set(__self__, "log_backup_enabled_time", log_backup_enabled_time)
        if retent_type is not None:
            pulumi.set(__self__, "retent_type", retent_type)
        if retention is not None:
            pulumi.set(__self__, "retention", retention)

    @property
    @pulumi.getter(name="backupEnabled")
    def backup_enabled(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the overall cross-region backup switch on the instance. Valid values:
        - Disabled
        - Enable
        """
        return pulumi.get(self, "backup_enabled")

    @backup_enabled.setter
    def backup_enabled(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "backup_enabled", value)

    @property
    @pulumi.getter(name="backupEnabledTime")
    def backup_enabled_time(self) -> Optional[pulumi.Input[str]]:
        """
        The time when cross-region backup was enabled on the instance. The time follows the ISO 8601 standard in the yyyy-MM-ddTHH:mm:ssZ format. The time is displayed in UTC.
        """
        return pulumi.get(self, "backup_enabled_time")

    @backup_enabled_time.setter
    def backup_enabled_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "backup_enabled_time", value)

    @property
    @pulumi.getter(name="crossBackupRegion")
    def cross_backup_region(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the destination region where the cross-region backup files of the instance are stored.
        """
        return pulumi.get(self, "cross_backup_region")

    @cross_backup_region.setter
    def cross_backup_region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cross_backup_region", value)

    @property
    @pulumi.getter(name="crossBackupType")
    def cross_backup_type(self) -> Optional[pulumi.Input[str]]:
        """
        The policy that is used to save cross-region backups of the instance. Default value: 1. The default value 1 indicates that all cross-region backups are saved.
        """
        return pulumi.get(self, "cross_backup_type")

    @cross_backup_type.setter
    def cross_backup_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cross_backup_type", value)

    @property
    @pulumi.getter(name="dbInstanceStatus")
    def db_instance_status(self) -> Optional[pulumi.Input[str]]:
        """
        The state of the instance. For more information, see Instance status.
        """
        return pulumi.get(self, "db_instance_status")

    @db_instance_status.setter
    def db_instance_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "db_instance_status", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the instance.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="lockMode")
    def lock_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The lock status of the instance. Valid values:
        - Unlock: The instance is not locked.
        - ManualLock: The instance is manually locked.
        - LockByExpiration: The instance is locked upon expiration.
        - LockByRestoration: The instance is automatically locked before a rollback.
        - LockByDiskQuota: The instance is automatically locked because its storage space is exhausted. In this situation, the instance is inaccessible.
        """
        return pulumi.get(self, "lock_mode")

    @lock_mode.setter
    def lock_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lock_mode", value)

    @property
    @pulumi.getter(name="logBackupEnabled")
    def log_backup_enabled(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the cross-region log backup feature on the instance. Valid values:
        - Enable: Enables the feature.
        - Disabled: Disables the feature.
        """
        return pulumi.get(self, "log_backup_enabled")

    @log_backup_enabled.setter
    def log_backup_enabled(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "log_backup_enabled", value)

    @property
    @pulumi.getter(name="logBackupEnabledTime")
    def log_backup_enabled_time(self) -> Optional[pulumi.Input[str]]:
        """
        The time when cross-region log backup was enabled on the instance. The time follows the ISO 8601 standard in the yyyy-MM-ddTHH:mm:ssZ format. The time is displayed in UTC.
        """
        return pulumi.get(self, "log_backup_enabled_time")

    @log_backup_enabled_time.setter
    def log_backup_enabled_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "log_backup_enabled_time", value)

    @property
    @pulumi.getter(name="retentType")
    def retent_type(self) -> Optional[pulumi.Input[str]]:
        """
        The policy that is used to retain cross-region backups of the instance. Default value: 1. The default value 1 indicate that cross-region backups are retained based on the specified retention period.
        """
        return pulumi.get(self, "retent_type")

    @retent_type.setter
    def retent_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "retent_type", value)

    @property
    @pulumi.getter
    def retention(self) -> Optional[pulumi.Input[int]]:
        """
        The number of days for which the cross-region backup files of the instance are retained. Valid values: 7 to 1825. Default value: 7.
        """
        return pulumi.get(self, "retention")

    @retention.setter
    def retention(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "retention", value)


class RdsInstanceCrossBackupPolicy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cross_backup_region: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 log_backup_enabled: Optional[pulumi.Input[str]] = None,
                 retention: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        Provides an RDS instance emote disaster recovery strategy policy resource and used to configure instance emote disaster recovery strategy policy.

        For information about RDS cross region backup settings and how to use them, see [What is cross region backup](https://www.alibabacloud.com/help/en/apsaradb-for-rds/latest/modify-cross-region-backup-settings).

        > **NOTE:** Available since v1.195.0.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default = alicloud.rds.get_zones(engine="MySQL",
            engine_version="8.0",
            db_instance_storage_type="local_ssd",
            category="HighAvailability")
        default_get_instance_classes = alicloud.rds.get_instance_classes(zone_id=default.ids[0],
            engine="MySQL",
            engine_version="8.0",
            db_instance_storage_type="local_ssd",
            category="HighAvailability")
        regions = alicloud.rds.get_cross_regions()
        default_network = alicloud.vpc.Network("default",
            vpc_name=name,
            cidr_block="172.16.0.0/16")
        default_switch = alicloud.vpc.Switch("default",
            vpc_id=default_network.id,
            cidr_block="172.16.0.0/24",
            zone_id=default.ids[0],
            vswitch_name=name)
        default_instance = alicloud.rds.Instance("default",
            engine="MySQL",
            engine_version="8.0",
            instance_type=default_get_instance_classes.instance_classes[0].instance_class,
            instance_storage=default_get_instance_classes.instance_classes[0].storage_range.min,
            instance_charge_type="Postpaid",
            category="HighAvailability",
            instance_name=name,
            vswitch_id=default_switch.id,
            db_instance_storage_type="local_ssd")
        default_rds_instance_cross_backup_policy = alicloud.rds.RdsInstanceCrossBackupPolicy("default",
            instance_id=default_instance.id,
            cross_backup_region=regions.ids[0])
        ```

        ## Import

        RDS remote disaster recovery policies can be imported using id or instance id, e.g.

        ```sh
        $ pulumi import alicloud:rds/rdsInstanceCrossBackupPolicy:RdsInstanceCrossBackupPolicy example "rm-12345678"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cross_backup_region: The ID of the destination region where the cross-region backup files of the instance are stored.
        :param pulumi.Input[str] instance_id: The ID of the instance.
        :param pulumi.Input[str] log_backup_enabled: The status of the cross-region log backup feature on the instance. Valid values:
               - Enable: Enables the feature.
               - Disabled: Disables the feature.
        :param pulumi.Input[int] retention: The number of days for which the cross-region backup files of the instance are retained. Valid values: 7 to 1825. Default value: 7.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RdsInstanceCrossBackupPolicyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides an RDS instance emote disaster recovery strategy policy resource and used to configure instance emote disaster recovery strategy policy.

        For information about RDS cross region backup settings and how to use them, see [What is cross region backup](https://www.alibabacloud.com/help/en/apsaradb-for-rds/latest/modify-cross-region-backup-settings).

        > **NOTE:** Available since v1.195.0.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default = alicloud.rds.get_zones(engine="MySQL",
            engine_version="8.0",
            db_instance_storage_type="local_ssd",
            category="HighAvailability")
        default_get_instance_classes = alicloud.rds.get_instance_classes(zone_id=default.ids[0],
            engine="MySQL",
            engine_version="8.0",
            db_instance_storage_type="local_ssd",
            category="HighAvailability")
        regions = alicloud.rds.get_cross_regions()
        default_network = alicloud.vpc.Network("default",
            vpc_name=name,
            cidr_block="172.16.0.0/16")
        default_switch = alicloud.vpc.Switch("default",
            vpc_id=default_network.id,
            cidr_block="172.16.0.0/24",
            zone_id=default.ids[0],
            vswitch_name=name)
        default_instance = alicloud.rds.Instance("default",
            engine="MySQL",
            engine_version="8.0",
            instance_type=default_get_instance_classes.instance_classes[0].instance_class,
            instance_storage=default_get_instance_classes.instance_classes[0].storage_range.min,
            instance_charge_type="Postpaid",
            category="HighAvailability",
            instance_name=name,
            vswitch_id=default_switch.id,
            db_instance_storage_type="local_ssd")
        default_rds_instance_cross_backup_policy = alicloud.rds.RdsInstanceCrossBackupPolicy("default",
            instance_id=default_instance.id,
            cross_backup_region=regions.ids[0])
        ```

        ## Import

        RDS remote disaster recovery policies can be imported using id or instance id, e.g.

        ```sh
        $ pulumi import alicloud:rds/rdsInstanceCrossBackupPolicy:RdsInstanceCrossBackupPolicy example "rm-12345678"
        ```

        :param str resource_name: The name of the resource.
        :param RdsInstanceCrossBackupPolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RdsInstanceCrossBackupPolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cross_backup_region: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 log_backup_enabled: Optional[pulumi.Input[str]] = None,
                 retention: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RdsInstanceCrossBackupPolicyArgs.__new__(RdsInstanceCrossBackupPolicyArgs)

            if cross_backup_region is None and not opts.urn:
                raise TypeError("Missing required property 'cross_backup_region'")
            __props__.__dict__["cross_backup_region"] = cross_backup_region
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["log_backup_enabled"] = log_backup_enabled
            __props__.__dict__["retention"] = retention
            __props__.__dict__["backup_enabled"] = None
            __props__.__dict__["backup_enabled_time"] = None
            __props__.__dict__["cross_backup_type"] = None
            __props__.__dict__["db_instance_status"] = None
            __props__.__dict__["lock_mode"] = None
            __props__.__dict__["log_backup_enabled_time"] = None
            __props__.__dict__["retent_type"] = None
        super(RdsInstanceCrossBackupPolicy, __self__).__init__(
            'alicloud:rds/rdsInstanceCrossBackupPolicy:RdsInstanceCrossBackupPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            backup_enabled: Optional[pulumi.Input[str]] = None,
            backup_enabled_time: Optional[pulumi.Input[str]] = None,
            cross_backup_region: Optional[pulumi.Input[str]] = None,
            cross_backup_type: Optional[pulumi.Input[str]] = None,
            db_instance_status: Optional[pulumi.Input[str]] = None,
            instance_id: Optional[pulumi.Input[str]] = None,
            lock_mode: Optional[pulumi.Input[str]] = None,
            log_backup_enabled: Optional[pulumi.Input[str]] = None,
            log_backup_enabled_time: Optional[pulumi.Input[str]] = None,
            retent_type: Optional[pulumi.Input[str]] = None,
            retention: Optional[pulumi.Input[int]] = None) -> 'RdsInstanceCrossBackupPolicy':
        """
        Get an existing RdsInstanceCrossBackupPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] backup_enabled: The status of the overall cross-region backup switch on the instance. Valid values:
               - Disabled
               - Enable
        :param pulumi.Input[str] backup_enabled_time: The time when cross-region backup was enabled on the instance. The time follows the ISO 8601 standard in the yyyy-MM-ddTHH:mm:ssZ format. The time is displayed in UTC.
        :param pulumi.Input[str] cross_backup_region: The ID of the destination region where the cross-region backup files of the instance are stored.
        :param pulumi.Input[str] cross_backup_type: The policy that is used to save cross-region backups of the instance. Default value: 1. The default value 1 indicates that all cross-region backups are saved.
        :param pulumi.Input[str] db_instance_status: The state of the instance. For more information, see Instance status.
        :param pulumi.Input[str] instance_id: The ID of the instance.
        :param pulumi.Input[str] lock_mode: The lock status of the instance. Valid values:
               - Unlock: The instance is not locked.
               - ManualLock: The instance is manually locked.
               - LockByExpiration: The instance is locked upon expiration.
               - LockByRestoration: The instance is automatically locked before a rollback.
               - LockByDiskQuota: The instance is automatically locked because its storage space is exhausted. In this situation, the instance is inaccessible.
        :param pulumi.Input[str] log_backup_enabled: The status of the cross-region log backup feature on the instance. Valid values:
               - Enable: Enables the feature.
               - Disabled: Disables the feature.
        :param pulumi.Input[str] log_backup_enabled_time: The time when cross-region log backup was enabled on the instance. The time follows the ISO 8601 standard in the yyyy-MM-ddTHH:mm:ssZ format. The time is displayed in UTC.
        :param pulumi.Input[str] retent_type: The policy that is used to retain cross-region backups of the instance. Default value: 1. The default value 1 indicate that cross-region backups are retained based on the specified retention period.
        :param pulumi.Input[int] retention: The number of days for which the cross-region backup files of the instance are retained. Valid values: 7 to 1825. Default value: 7.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RdsInstanceCrossBackupPolicyState.__new__(_RdsInstanceCrossBackupPolicyState)

        __props__.__dict__["backup_enabled"] = backup_enabled
        __props__.__dict__["backup_enabled_time"] = backup_enabled_time
        __props__.__dict__["cross_backup_region"] = cross_backup_region
        __props__.__dict__["cross_backup_type"] = cross_backup_type
        __props__.__dict__["db_instance_status"] = db_instance_status
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["lock_mode"] = lock_mode
        __props__.__dict__["log_backup_enabled"] = log_backup_enabled
        __props__.__dict__["log_backup_enabled_time"] = log_backup_enabled_time
        __props__.__dict__["retent_type"] = retent_type
        __props__.__dict__["retention"] = retention
        return RdsInstanceCrossBackupPolicy(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="backupEnabled")
    def backup_enabled(self) -> pulumi.Output[str]:
        """
        The status of the overall cross-region backup switch on the instance. Valid values:
        - Disabled
        - Enable
        """
        return pulumi.get(self, "backup_enabled")

    @property
    @pulumi.getter(name="backupEnabledTime")
    def backup_enabled_time(self) -> pulumi.Output[str]:
        """
        The time when cross-region backup was enabled on the instance. The time follows the ISO 8601 standard in the yyyy-MM-ddTHH:mm:ssZ format. The time is displayed in UTC.
        """
        return pulumi.get(self, "backup_enabled_time")

    @property
    @pulumi.getter(name="crossBackupRegion")
    def cross_backup_region(self) -> pulumi.Output[str]:
        """
        The ID of the destination region where the cross-region backup files of the instance are stored.
        """
        return pulumi.get(self, "cross_backup_region")

    @property
    @pulumi.getter(name="crossBackupType")
    def cross_backup_type(self) -> pulumi.Output[str]:
        """
        The policy that is used to save cross-region backups of the instance. Default value: 1. The default value 1 indicates that all cross-region backups are saved.
        """
        return pulumi.get(self, "cross_backup_type")

    @property
    @pulumi.getter(name="dbInstanceStatus")
    def db_instance_status(self) -> pulumi.Output[str]:
        """
        The state of the instance. For more information, see Instance status.
        """
        return pulumi.get(self, "db_instance_status")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[str]:
        """
        The ID of the instance.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="lockMode")
    def lock_mode(self) -> pulumi.Output[str]:
        """
        The lock status of the instance. Valid values:
        - Unlock: The instance is not locked.
        - ManualLock: The instance is manually locked.
        - LockByExpiration: The instance is locked upon expiration.
        - LockByRestoration: The instance is automatically locked before a rollback.
        - LockByDiskQuota: The instance is automatically locked because its storage space is exhausted. In this situation, the instance is inaccessible.
        """
        return pulumi.get(self, "lock_mode")

    @property
    @pulumi.getter(name="logBackupEnabled")
    def log_backup_enabled(self) -> pulumi.Output[str]:
        """
        The status of the cross-region log backup feature on the instance. Valid values:
        - Enable: Enables the feature.
        - Disabled: Disables the feature.
        """
        return pulumi.get(self, "log_backup_enabled")

    @property
    @pulumi.getter(name="logBackupEnabledTime")
    def log_backup_enabled_time(self) -> pulumi.Output[str]:
        """
        The time when cross-region log backup was enabled on the instance. The time follows the ISO 8601 standard in the yyyy-MM-ddTHH:mm:ssZ format. The time is displayed in UTC.
        """
        return pulumi.get(self, "log_backup_enabled_time")

    @property
    @pulumi.getter(name="retentType")
    def retent_type(self) -> pulumi.Output[str]:
        """
        The policy that is used to retain cross-region backups of the instance. Default value: 1. The default value 1 indicate that cross-region backups are retained based on the specified retention period.
        """
        return pulumi.get(self, "retent_type")

    @property
    @pulumi.getter
    def retention(self) -> pulumi.Output[int]:
        """
        The number of days for which the cross-region backup files of the instance are retained. Valid values: 7 to 1825. Default value: 7.
        """
        return pulumi.get(self, "retention")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DomainArgs', 'Domain']

@pulumi.input_type
class DomainArgs:
    def __init__(__self__, *,
                 cdn_type: pulumi.Input[str],
                 domain_name: pulumi.Input[str],
                 auth_config: Optional[pulumi.Input['DomainAuthConfigArgs']] = None,
                 block_ips: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cache_configs: Optional[pulumi.Input[Sequence[pulumi.Input['DomainCacheConfigArgs']]]] = None,
                 certificate_config: Optional[pulumi.Input['DomainCertificateConfigArgs']] = None,
                 http_header_configs: Optional[pulumi.Input[Sequence[pulumi.Input['DomainHttpHeaderConfigArgs']]]] = None,
                 optimize_enable: Optional[pulumi.Input[str]] = None,
                 page404_config: Optional[pulumi.Input['DomainPage404ConfigArgs']] = None,
                 page_compress_enable: Optional[pulumi.Input[str]] = None,
                 parameter_filter_config: Optional[pulumi.Input['DomainParameterFilterConfigArgs']] = None,
                 range_enable: Optional[pulumi.Input[str]] = None,
                 refer_config: Optional[pulumi.Input['DomainReferConfigArgs']] = None,
                 scope: Optional[pulumi.Input[str]] = None,
                 source_port: Optional[pulumi.Input[int]] = None,
                 source_type: Optional[pulumi.Input[str]] = None,
                 sources: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 video_seek_enable: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Domain resource.
        """
        pulumi.set(__self__, "cdn_type", cdn_type)
        pulumi.set(__self__, "domain_name", domain_name)
        if auth_config is not None:
            warnings.warn("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""", DeprecationWarning)
            pulumi.log.warn("""auth_config is deprecated: Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
        if auth_config is not None:
            pulumi.set(__self__, "auth_config", auth_config)
        if block_ips is not None:
            warnings.warn("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""", DeprecationWarning)
            pulumi.log.warn("""block_ips is deprecated: Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
        if block_ips is not None:
            pulumi.set(__self__, "block_ips", block_ips)
        if cache_configs is not None:
            warnings.warn("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""", DeprecationWarning)
            pulumi.log.warn("""cache_configs is deprecated: Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
        if cache_configs is not None:
            pulumi.set(__self__, "cache_configs", cache_configs)
        if certificate_config is not None:
            warnings.warn("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""", DeprecationWarning)
            pulumi.log.warn("""certificate_config is deprecated: Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
        if certificate_config is not None:
            pulumi.set(__self__, "certificate_config", certificate_config)
        if http_header_configs is not None:
            warnings.warn("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""", DeprecationWarning)
            pulumi.log.warn("""http_header_configs is deprecated: Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
        if http_header_configs is not None:
            pulumi.set(__self__, "http_header_configs", http_header_configs)
        if optimize_enable is not None:
            warnings.warn("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""", DeprecationWarning)
            pulumi.log.warn("""optimize_enable is deprecated: Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
        if optimize_enable is not None:
            pulumi.set(__self__, "optimize_enable", optimize_enable)
        if page404_config is not None:
            warnings.warn("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""", DeprecationWarning)
            pulumi.log.warn("""page404_config is deprecated: Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
        if page404_config is not None:
            pulumi.set(__self__, "page404_config", page404_config)
        if page_compress_enable is not None:
            warnings.warn("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""", DeprecationWarning)
            pulumi.log.warn("""page_compress_enable is deprecated: Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
        if page_compress_enable is not None:
            pulumi.set(__self__, "page_compress_enable", page_compress_enable)
        if parameter_filter_config is not None:
            warnings.warn("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""", DeprecationWarning)
            pulumi.log.warn("""parameter_filter_config is deprecated: Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
        if parameter_filter_config is not None:
            pulumi.set(__self__, "parameter_filter_config", parameter_filter_config)
        if range_enable is not None:
            warnings.warn("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""", DeprecationWarning)
            pulumi.log.warn("""range_enable is deprecated: Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
        if range_enable is not None:
            pulumi.set(__self__, "range_enable", range_enable)
        if refer_config is not None:
            warnings.warn("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""", DeprecationWarning)
            pulumi.log.warn("""refer_config is deprecated: Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
        if refer_config is not None:
            pulumi.set(__self__, "refer_config", refer_config)
        if scope is not None:
            pulumi.set(__self__, "scope", scope)
        if source_port is not None:
            warnings.warn("""Use `cdn.DomainNew` configuration `sources` block `port` argument instead.""", DeprecationWarning)
            pulumi.log.warn("""source_port is deprecated: Use `cdn.DomainNew` configuration `sources` block `port` argument instead.""")
        if source_port is not None:
            pulumi.set(__self__, "source_port", source_port)
        if source_type is not None:
            warnings.warn("""Use `cdn.DomainNew` configuration `sources` block `type` argument instead.""", DeprecationWarning)
            pulumi.log.warn("""source_type is deprecated: Use `cdn.DomainNew` configuration `sources` block `type` argument instead.""")
        if source_type is not None:
            pulumi.set(__self__, "source_type", source_type)
        if sources is not None:
            warnings.warn("""Use `cdn.DomainNew` configuration `sources` argument instead.""", DeprecationWarning)
            pulumi.log.warn("""sources is deprecated: Use `cdn.DomainNew` configuration `sources` argument instead.""")
        if sources is not None:
            pulumi.set(__self__, "sources", sources)
        if video_seek_enable is not None:
            warnings.warn("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""", DeprecationWarning)
            pulumi.log.warn("""video_seek_enable is deprecated: Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
        if video_seek_enable is not None:
            pulumi.set(__self__, "video_seek_enable", video_seek_enable)

    @property
    @pulumi.getter(name="cdnType")
    def cdn_type(self) -> pulumi.Input[str]:
        return pulumi.get(self, "cdn_type")

    @cdn_type.setter
    def cdn_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "cdn_type", value)

    @property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> pulumi.Input[str]:
        return pulumi.get(self, "domain_name")

    @domain_name.setter
    def domain_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "domain_name", value)

    @property
    @pulumi.getter(name="authConfig")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def auth_config(self) -> Optional[pulumi.Input['DomainAuthConfigArgs']]:
        return pulumi.get(self, "auth_config")

    @auth_config.setter
    def auth_config(self, value: Optional[pulumi.Input['DomainAuthConfigArgs']]):
        pulumi.set(self, "auth_config", value)

    @property
    @pulumi.getter(name="blockIps")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def block_ips(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "block_ips")

    @block_ips.setter
    def block_ips(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "block_ips", value)

    @property
    @pulumi.getter(name="cacheConfigs")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def cache_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DomainCacheConfigArgs']]]]:
        return pulumi.get(self, "cache_configs")

    @cache_configs.setter
    def cache_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DomainCacheConfigArgs']]]]):
        pulumi.set(self, "cache_configs", value)

    @property
    @pulumi.getter(name="certificateConfig")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def certificate_config(self) -> Optional[pulumi.Input['DomainCertificateConfigArgs']]:
        return pulumi.get(self, "certificate_config")

    @certificate_config.setter
    def certificate_config(self, value: Optional[pulumi.Input['DomainCertificateConfigArgs']]):
        pulumi.set(self, "certificate_config", value)

    @property
    @pulumi.getter(name="httpHeaderConfigs")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def http_header_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DomainHttpHeaderConfigArgs']]]]:
        return pulumi.get(self, "http_header_configs")

    @http_header_configs.setter
    def http_header_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DomainHttpHeaderConfigArgs']]]]):
        pulumi.set(self, "http_header_configs", value)

    @property
    @pulumi.getter(name="optimizeEnable")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def optimize_enable(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "optimize_enable")

    @optimize_enable.setter
    def optimize_enable(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "optimize_enable", value)

    @property
    @pulumi.getter(name="page404Config")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def page404_config(self) -> Optional[pulumi.Input['DomainPage404ConfigArgs']]:
        return pulumi.get(self, "page404_config")

    @page404_config.setter
    def page404_config(self, value: Optional[pulumi.Input['DomainPage404ConfigArgs']]):
        pulumi.set(self, "page404_config", value)

    @property
    @pulumi.getter(name="pageCompressEnable")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def page_compress_enable(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "page_compress_enable")

    @page_compress_enable.setter
    def page_compress_enable(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "page_compress_enable", value)

    @property
    @pulumi.getter(name="parameterFilterConfig")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def parameter_filter_config(self) -> Optional[pulumi.Input['DomainParameterFilterConfigArgs']]:
        return pulumi.get(self, "parameter_filter_config")

    @parameter_filter_config.setter
    def parameter_filter_config(self, value: Optional[pulumi.Input['DomainParameterFilterConfigArgs']]):
        pulumi.set(self, "parameter_filter_config", value)

    @property
    @pulumi.getter(name="rangeEnable")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def range_enable(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "range_enable")

    @range_enable.setter
    def range_enable(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "range_enable", value)

    @property
    @pulumi.getter(name="referConfig")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def refer_config(self) -> Optional[pulumi.Input['DomainReferConfigArgs']]:
        return pulumi.get(self, "refer_config")

    @refer_config.setter
    def refer_config(self, value: Optional[pulumi.Input['DomainReferConfigArgs']]):
        pulumi.set(self, "refer_config", value)

    @property
    @pulumi.getter
    def scope(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "scope")

    @scope.setter
    def scope(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "scope", value)

    @property
    @pulumi.getter(name="sourcePort")
    @_utilities.deprecated("""Use `cdn.DomainNew` configuration `sources` block `port` argument instead.""")
    def source_port(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "source_port")

    @source_port.setter
    def source_port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "source_port", value)

    @property
    @pulumi.getter(name="sourceType")
    @_utilities.deprecated("""Use `cdn.DomainNew` configuration `sources` block `type` argument instead.""")
    def source_type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "source_type")

    @source_type.setter
    def source_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_type", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Use `cdn.DomainNew` configuration `sources` argument instead.""")
    def sources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "sources")

    @sources.setter
    def sources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "sources", value)

    @property
    @pulumi.getter(name="videoSeekEnable")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def video_seek_enable(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "video_seek_enable")

    @video_seek_enable.setter
    def video_seek_enable(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "video_seek_enable", value)


@pulumi.input_type
class _DomainState:
    def __init__(__self__, *,
                 auth_config: Optional[pulumi.Input['DomainAuthConfigArgs']] = None,
                 block_ips: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cache_configs: Optional[pulumi.Input[Sequence[pulumi.Input['DomainCacheConfigArgs']]]] = None,
                 cdn_type: Optional[pulumi.Input[str]] = None,
                 certificate_config: Optional[pulumi.Input['DomainCertificateConfigArgs']] = None,
                 domain_name: Optional[pulumi.Input[str]] = None,
                 http_header_configs: Optional[pulumi.Input[Sequence[pulumi.Input['DomainHttpHeaderConfigArgs']]]] = None,
                 optimize_enable: Optional[pulumi.Input[str]] = None,
                 page404_config: Optional[pulumi.Input['DomainPage404ConfigArgs']] = None,
                 page_compress_enable: Optional[pulumi.Input[str]] = None,
                 parameter_filter_config: Optional[pulumi.Input['DomainParameterFilterConfigArgs']] = None,
                 range_enable: Optional[pulumi.Input[str]] = None,
                 refer_config: Optional[pulumi.Input['DomainReferConfigArgs']] = None,
                 scope: Optional[pulumi.Input[str]] = None,
                 source_port: Optional[pulumi.Input[int]] = None,
                 source_type: Optional[pulumi.Input[str]] = None,
                 sources: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 video_seek_enable: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Domain resources.
        """
        if auth_config is not None:
            warnings.warn("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""", DeprecationWarning)
            pulumi.log.warn("""auth_config is deprecated: Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
        if auth_config is not None:
            pulumi.set(__self__, "auth_config", auth_config)
        if block_ips is not None:
            warnings.warn("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""", DeprecationWarning)
            pulumi.log.warn("""block_ips is deprecated: Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
        if block_ips is not None:
            pulumi.set(__self__, "block_ips", block_ips)
        if cache_configs is not None:
            warnings.warn("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""", DeprecationWarning)
            pulumi.log.warn("""cache_configs is deprecated: Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
        if cache_configs is not None:
            pulumi.set(__self__, "cache_configs", cache_configs)
        if cdn_type is not None:
            pulumi.set(__self__, "cdn_type", cdn_type)
        if certificate_config is not None:
            warnings.warn("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""", DeprecationWarning)
            pulumi.log.warn("""certificate_config is deprecated: Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
        if certificate_config is not None:
            pulumi.set(__self__, "certificate_config", certificate_config)
        if domain_name is not None:
            pulumi.set(__self__, "domain_name", domain_name)
        if http_header_configs is not None:
            warnings.warn("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""", DeprecationWarning)
            pulumi.log.warn("""http_header_configs is deprecated: Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
        if http_header_configs is not None:
            pulumi.set(__self__, "http_header_configs", http_header_configs)
        if optimize_enable is not None:
            warnings.warn("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""", DeprecationWarning)
            pulumi.log.warn("""optimize_enable is deprecated: Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
        if optimize_enable is not None:
            pulumi.set(__self__, "optimize_enable", optimize_enable)
        if page404_config is not None:
            warnings.warn("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""", DeprecationWarning)
            pulumi.log.warn("""page404_config is deprecated: Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
        if page404_config is not None:
            pulumi.set(__self__, "page404_config", page404_config)
        if page_compress_enable is not None:
            warnings.warn("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""", DeprecationWarning)
            pulumi.log.warn("""page_compress_enable is deprecated: Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
        if page_compress_enable is not None:
            pulumi.set(__self__, "page_compress_enable", page_compress_enable)
        if parameter_filter_config is not None:
            warnings.warn("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""", DeprecationWarning)
            pulumi.log.warn("""parameter_filter_config is deprecated: Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
        if parameter_filter_config is not None:
            pulumi.set(__self__, "parameter_filter_config", parameter_filter_config)
        if range_enable is not None:
            warnings.warn("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""", DeprecationWarning)
            pulumi.log.warn("""range_enable is deprecated: Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
        if range_enable is not None:
            pulumi.set(__self__, "range_enable", range_enable)
        if refer_config is not None:
            warnings.warn("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""", DeprecationWarning)
            pulumi.log.warn("""refer_config is deprecated: Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
        if refer_config is not None:
            pulumi.set(__self__, "refer_config", refer_config)
        if scope is not None:
            pulumi.set(__self__, "scope", scope)
        if source_port is not None:
            warnings.warn("""Use `cdn.DomainNew` configuration `sources` block `port` argument instead.""", DeprecationWarning)
            pulumi.log.warn("""source_port is deprecated: Use `cdn.DomainNew` configuration `sources` block `port` argument instead.""")
        if source_port is not None:
            pulumi.set(__self__, "source_port", source_port)
        if source_type is not None:
            warnings.warn("""Use `cdn.DomainNew` configuration `sources` block `type` argument instead.""", DeprecationWarning)
            pulumi.log.warn("""source_type is deprecated: Use `cdn.DomainNew` configuration `sources` block `type` argument instead.""")
        if source_type is not None:
            pulumi.set(__self__, "source_type", source_type)
        if sources is not None:
            warnings.warn("""Use `cdn.DomainNew` configuration `sources` argument instead.""", DeprecationWarning)
            pulumi.log.warn("""sources is deprecated: Use `cdn.DomainNew` configuration `sources` argument instead.""")
        if sources is not None:
            pulumi.set(__self__, "sources", sources)
        if video_seek_enable is not None:
            warnings.warn("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""", DeprecationWarning)
            pulumi.log.warn("""video_seek_enable is deprecated: Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
        if video_seek_enable is not None:
            pulumi.set(__self__, "video_seek_enable", video_seek_enable)

    @property
    @pulumi.getter(name="authConfig")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def auth_config(self) -> Optional[pulumi.Input['DomainAuthConfigArgs']]:
        return pulumi.get(self, "auth_config")

    @auth_config.setter
    def auth_config(self, value: Optional[pulumi.Input['DomainAuthConfigArgs']]):
        pulumi.set(self, "auth_config", value)

    @property
    @pulumi.getter(name="blockIps")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def block_ips(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "block_ips")

    @block_ips.setter
    def block_ips(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "block_ips", value)

    @property
    @pulumi.getter(name="cacheConfigs")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def cache_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DomainCacheConfigArgs']]]]:
        return pulumi.get(self, "cache_configs")

    @cache_configs.setter
    def cache_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DomainCacheConfigArgs']]]]):
        pulumi.set(self, "cache_configs", value)

    @property
    @pulumi.getter(name="cdnType")
    def cdn_type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "cdn_type")

    @cdn_type.setter
    def cdn_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cdn_type", value)

    @property
    @pulumi.getter(name="certificateConfig")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def certificate_config(self) -> Optional[pulumi.Input['DomainCertificateConfigArgs']]:
        return pulumi.get(self, "certificate_config")

    @certificate_config.setter
    def certificate_config(self, value: Optional[pulumi.Input['DomainCertificateConfigArgs']]):
        pulumi.set(self, "certificate_config", value)

    @property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "domain_name")

    @domain_name.setter
    def domain_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "domain_name", value)

    @property
    @pulumi.getter(name="httpHeaderConfigs")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def http_header_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DomainHttpHeaderConfigArgs']]]]:
        return pulumi.get(self, "http_header_configs")

    @http_header_configs.setter
    def http_header_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DomainHttpHeaderConfigArgs']]]]):
        pulumi.set(self, "http_header_configs", value)

    @property
    @pulumi.getter(name="optimizeEnable")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def optimize_enable(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "optimize_enable")

    @optimize_enable.setter
    def optimize_enable(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "optimize_enable", value)

    @property
    @pulumi.getter(name="page404Config")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def page404_config(self) -> Optional[pulumi.Input['DomainPage404ConfigArgs']]:
        return pulumi.get(self, "page404_config")

    @page404_config.setter
    def page404_config(self, value: Optional[pulumi.Input['DomainPage404ConfigArgs']]):
        pulumi.set(self, "page404_config", value)

    @property
    @pulumi.getter(name="pageCompressEnable")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def page_compress_enable(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "page_compress_enable")

    @page_compress_enable.setter
    def page_compress_enable(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "page_compress_enable", value)

    @property
    @pulumi.getter(name="parameterFilterConfig")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def parameter_filter_config(self) -> Optional[pulumi.Input['DomainParameterFilterConfigArgs']]:
        return pulumi.get(self, "parameter_filter_config")

    @parameter_filter_config.setter
    def parameter_filter_config(self, value: Optional[pulumi.Input['DomainParameterFilterConfigArgs']]):
        pulumi.set(self, "parameter_filter_config", value)

    @property
    @pulumi.getter(name="rangeEnable")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def range_enable(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "range_enable")

    @range_enable.setter
    def range_enable(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "range_enable", value)

    @property
    @pulumi.getter(name="referConfig")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def refer_config(self) -> Optional[pulumi.Input['DomainReferConfigArgs']]:
        return pulumi.get(self, "refer_config")

    @refer_config.setter
    def refer_config(self, value: Optional[pulumi.Input['DomainReferConfigArgs']]):
        pulumi.set(self, "refer_config", value)

    @property
    @pulumi.getter
    def scope(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "scope")

    @scope.setter
    def scope(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "scope", value)

    @property
    @pulumi.getter(name="sourcePort")
    @_utilities.deprecated("""Use `cdn.DomainNew` configuration `sources` block `port` argument instead.""")
    def source_port(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "source_port")

    @source_port.setter
    def source_port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "source_port", value)

    @property
    @pulumi.getter(name="sourceType")
    @_utilities.deprecated("""Use `cdn.DomainNew` configuration `sources` block `type` argument instead.""")
    def source_type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "source_type")

    @source_type.setter
    def source_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_type", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Use `cdn.DomainNew` configuration `sources` argument instead.""")
    def sources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "sources")

    @sources.setter
    def sources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "sources", value)

    @property
    @pulumi.getter(name="videoSeekEnable")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def video_seek_enable(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "video_seek_enable")

    @video_seek_enable.setter
    def video_seek_enable(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "video_seek_enable", value)


class Domain(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_config: Optional[pulumi.Input[Union['DomainAuthConfigArgs', 'DomainAuthConfigArgsDict']]] = None,
                 block_ips: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cache_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DomainCacheConfigArgs', 'DomainCacheConfigArgsDict']]]]] = None,
                 cdn_type: Optional[pulumi.Input[str]] = None,
                 certificate_config: Optional[pulumi.Input[Union['DomainCertificateConfigArgs', 'DomainCertificateConfigArgsDict']]] = None,
                 domain_name: Optional[pulumi.Input[str]] = None,
                 http_header_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DomainHttpHeaderConfigArgs', 'DomainHttpHeaderConfigArgsDict']]]]] = None,
                 optimize_enable: Optional[pulumi.Input[str]] = None,
                 page404_config: Optional[pulumi.Input[Union['DomainPage404ConfigArgs', 'DomainPage404ConfigArgsDict']]] = None,
                 page_compress_enable: Optional[pulumi.Input[str]] = None,
                 parameter_filter_config: Optional[pulumi.Input[Union['DomainParameterFilterConfigArgs', 'DomainParameterFilterConfigArgsDict']]] = None,
                 range_enable: Optional[pulumi.Input[str]] = None,
                 refer_config: Optional[pulumi.Input[Union['DomainReferConfigArgs', 'DomainReferConfigArgsDict']]] = None,
                 scope: Optional[pulumi.Input[str]] = None,
                 source_port: Optional[pulumi.Input[int]] = None,
                 source_type: Optional[pulumi.Input[str]] = None,
                 sources: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 video_seek_enable: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Create a Domain resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DomainArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a Domain resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param DomainArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DomainArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_config: Optional[pulumi.Input[Union['DomainAuthConfigArgs', 'DomainAuthConfigArgsDict']]] = None,
                 block_ips: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 cache_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DomainCacheConfigArgs', 'DomainCacheConfigArgsDict']]]]] = None,
                 cdn_type: Optional[pulumi.Input[str]] = None,
                 certificate_config: Optional[pulumi.Input[Union['DomainCertificateConfigArgs', 'DomainCertificateConfigArgsDict']]] = None,
                 domain_name: Optional[pulumi.Input[str]] = None,
                 http_header_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DomainHttpHeaderConfigArgs', 'DomainHttpHeaderConfigArgsDict']]]]] = None,
                 optimize_enable: Optional[pulumi.Input[str]] = None,
                 page404_config: Optional[pulumi.Input[Union['DomainPage404ConfigArgs', 'DomainPage404ConfigArgsDict']]] = None,
                 page_compress_enable: Optional[pulumi.Input[str]] = None,
                 parameter_filter_config: Optional[pulumi.Input[Union['DomainParameterFilterConfigArgs', 'DomainParameterFilterConfigArgsDict']]] = None,
                 range_enable: Optional[pulumi.Input[str]] = None,
                 refer_config: Optional[pulumi.Input[Union['DomainReferConfigArgs', 'DomainReferConfigArgsDict']]] = None,
                 scope: Optional[pulumi.Input[str]] = None,
                 source_port: Optional[pulumi.Input[int]] = None,
                 source_type: Optional[pulumi.Input[str]] = None,
                 sources: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 video_seek_enable: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DomainArgs.__new__(DomainArgs)

            __props__.__dict__["auth_config"] = auth_config
            __props__.__dict__["block_ips"] = block_ips
            __props__.__dict__["cache_configs"] = cache_configs
            if cdn_type is None and not opts.urn:
                raise TypeError("Missing required property 'cdn_type'")
            __props__.__dict__["cdn_type"] = cdn_type
            __props__.__dict__["certificate_config"] = certificate_config
            if domain_name is None and not opts.urn:
                raise TypeError("Missing required property 'domain_name'")
            __props__.__dict__["domain_name"] = domain_name
            __props__.__dict__["http_header_configs"] = http_header_configs
            __props__.__dict__["optimize_enable"] = optimize_enable
            __props__.__dict__["page404_config"] = page404_config
            __props__.__dict__["page_compress_enable"] = page_compress_enable
            __props__.__dict__["parameter_filter_config"] = parameter_filter_config
            __props__.__dict__["range_enable"] = range_enable
            __props__.__dict__["refer_config"] = refer_config
            __props__.__dict__["scope"] = scope
            __props__.__dict__["source_port"] = source_port
            __props__.__dict__["source_type"] = source_type
            __props__.__dict__["sources"] = sources
            __props__.__dict__["video_seek_enable"] = video_seek_enable
        super(Domain, __self__).__init__(
            'alicloud:cdn/domain:Domain',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auth_config: Optional[pulumi.Input[Union['DomainAuthConfigArgs', 'DomainAuthConfigArgsDict']]] = None,
            block_ips: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            cache_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DomainCacheConfigArgs', 'DomainCacheConfigArgsDict']]]]] = None,
            cdn_type: Optional[pulumi.Input[str]] = None,
            certificate_config: Optional[pulumi.Input[Union['DomainCertificateConfigArgs', 'DomainCertificateConfigArgsDict']]] = None,
            domain_name: Optional[pulumi.Input[str]] = None,
            http_header_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DomainHttpHeaderConfigArgs', 'DomainHttpHeaderConfigArgsDict']]]]] = None,
            optimize_enable: Optional[pulumi.Input[str]] = None,
            page404_config: Optional[pulumi.Input[Union['DomainPage404ConfigArgs', 'DomainPage404ConfigArgsDict']]] = None,
            page_compress_enable: Optional[pulumi.Input[str]] = None,
            parameter_filter_config: Optional[pulumi.Input[Union['DomainParameterFilterConfigArgs', 'DomainParameterFilterConfigArgsDict']]] = None,
            range_enable: Optional[pulumi.Input[str]] = None,
            refer_config: Optional[pulumi.Input[Union['DomainReferConfigArgs', 'DomainReferConfigArgsDict']]] = None,
            scope: Optional[pulumi.Input[str]] = None,
            source_port: Optional[pulumi.Input[int]] = None,
            source_type: Optional[pulumi.Input[str]] = None,
            sources: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            video_seek_enable: Optional[pulumi.Input[str]] = None) -> 'Domain':
        """
        Get an existing Domain resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DomainState.__new__(_DomainState)

        __props__.__dict__["auth_config"] = auth_config
        __props__.__dict__["block_ips"] = block_ips
        __props__.__dict__["cache_configs"] = cache_configs
        __props__.__dict__["cdn_type"] = cdn_type
        __props__.__dict__["certificate_config"] = certificate_config
        __props__.__dict__["domain_name"] = domain_name
        __props__.__dict__["http_header_configs"] = http_header_configs
        __props__.__dict__["optimize_enable"] = optimize_enable
        __props__.__dict__["page404_config"] = page404_config
        __props__.__dict__["page_compress_enable"] = page_compress_enable
        __props__.__dict__["parameter_filter_config"] = parameter_filter_config
        __props__.__dict__["range_enable"] = range_enable
        __props__.__dict__["refer_config"] = refer_config
        __props__.__dict__["scope"] = scope
        __props__.__dict__["source_port"] = source_port
        __props__.__dict__["source_type"] = source_type
        __props__.__dict__["sources"] = sources
        __props__.__dict__["video_seek_enable"] = video_seek_enable
        return Domain(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="authConfig")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def auth_config(self) -> pulumi.Output[Optional['outputs.DomainAuthConfig']]:
        return pulumi.get(self, "auth_config")

    @property
    @pulumi.getter(name="blockIps")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def block_ips(self) -> pulumi.Output[Optional[Sequence[str]]]:
        return pulumi.get(self, "block_ips")

    @property
    @pulumi.getter(name="cacheConfigs")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def cache_configs(self) -> pulumi.Output[Optional[Sequence['outputs.DomainCacheConfig']]]:
        return pulumi.get(self, "cache_configs")

    @property
    @pulumi.getter(name="cdnType")
    def cdn_type(self) -> pulumi.Output[str]:
        return pulumi.get(self, "cdn_type")

    @property
    @pulumi.getter(name="certificateConfig")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def certificate_config(self) -> pulumi.Output[Optional['outputs.DomainCertificateConfig']]:
        return pulumi.get(self, "certificate_config")

    @property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "domain_name")

    @property
    @pulumi.getter(name="httpHeaderConfigs")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def http_header_configs(self) -> pulumi.Output[Optional[Sequence['outputs.DomainHttpHeaderConfig']]]:
        return pulumi.get(self, "http_header_configs")

    @property
    @pulumi.getter(name="optimizeEnable")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def optimize_enable(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "optimize_enable")

    @property
    @pulumi.getter(name="page404Config")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def page404_config(self) -> pulumi.Output[Optional['outputs.DomainPage404Config']]:
        return pulumi.get(self, "page404_config")

    @property
    @pulumi.getter(name="pageCompressEnable")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def page_compress_enable(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "page_compress_enable")

    @property
    @pulumi.getter(name="parameterFilterConfig")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def parameter_filter_config(self) -> pulumi.Output[Optional['outputs.DomainParameterFilterConfig']]:
        return pulumi.get(self, "parameter_filter_config")

    @property
    @pulumi.getter(name="rangeEnable")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def range_enable(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "range_enable")

    @property
    @pulumi.getter(name="referConfig")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def refer_config(self) -> pulumi.Output[Optional['outputs.DomainReferConfig']]:
        return pulumi.get(self, "refer_config")

    @property
    @pulumi.getter
    def scope(self) -> pulumi.Output[str]:
        return pulumi.get(self, "scope")

    @property
    @pulumi.getter(name="sourcePort")
    @_utilities.deprecated("""Use `cdn.DomainNew` configuration `sources` block `port` argument instead.""")
    def source_port(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "source_port")

    @property
    @pulumi.getter(name="sourceType")
    @_utilities.deprecated("""Use `cdn.DomainNew` configuration `sources` block `type` argument instead.""")
    def source_type(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "source_type")

    @property
    @pulumi.getter
    @_utilities.deprecated("""Use `cdn.DomainNew` configuration `sources` argument instead.""")
    def sources(self) -> pulumi.Output[Optional[Sequence[str]]]:
        return pulumi.get(self, "sources")

    @property
    @pulumi.getter(name="videoSeekEnable")
    @_utilities.deprecated("""Use `cdn.DomainConfig` configuration `function_name` and `function_args` arguments instead.""")
    def video_seek_enable(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "video_seek_enable")

